@@ -81,7 +81,9 @@ class HelpTest(testutils.BaseTestCase):
     self.assertIn('NAME\n    triple', help_screen)
     self.assertIn('SYNOPSIS\n    triple <flags>', help_screen)
     self.assertNotIn('DESCRIPTION', help_screen)
-    self.assertIn('FLAGS\n    --count=COUNT\n        Default: 0', help_screen)
+    self.assertIn(
+        'FLAGS\n    -c, --count=COUNT\n        Default: 0',
+        help_screen)
     self.assertNotIn('NOTES', help_screen)
 
   def testHelpTextFunctionWithLongDefaults(self):
@@ -93,7 +95,7 @@ class HelpTest(testutils.BaseTestCase):
     self.assertIn('SYNOPSIS\n    text <flags>', help_screen)
     self.assertNotIn('DESCRIPTION', help_screen)
     self.assertIn(
-        'FLAGS\n    --string=STRING\n'
+        'FLAGS\n    -s, --string=STRING\n'
         '        Default: \'0001020304050607080910'
         '1112131415161718192021222324252627282...',
         help_screen)
@@ -121,7 +123,7 @@ class HelpTest(testutils.BaseTestCase):
     self.assertIn('SYNOPSIS\n    text ARG1 ARG2 <flags>', help_screen)
     self.assertIn('DESCRIPTION\n    Function with kwarg', help_screen)
     self.assertIn(
-        'FLAGS\n    --opt=OPT\n        Default: True\n'
+        'FLAGS\n    -o, --opt=OPT\n        Default: True\n'
         '    The following flags are also accepted.'
         '\n    --arg3\n        Description of arg3.\n    '
         'Additional undocumented flags may also be accepted.',
@@ -140,7 +142,7 @@ class HelpTest(testutils.BaseTestCase):
     self.assertIn('SYNOPSIS\n    double <flags>', help_screen)
     self.assertIn('DESCRIPTION', help_screen)
     self.assertIn(
-        'FLAGS\n    --count=COUNT\n        Type: float\n        Default: 0',
+        'FLAGS\n    -c, --count=COUNT\n        Type: float\n        Default: 0',
         help_screen)
     self.assertNotIn('NOTES', help_screen)
 
@@ -157,7 +159,7 @@ class HelpTest(testutils.BaseTestCase):
     self.assertIn('SYNOPSIS\n    get_int <flags>', help_screen)
     self.assertNotIn('DESCRIPTION', help_screen)
     self.assertIn(
-        'FLAGS\n    --value=VALUE\n'
+        'FLAGS\n    -v, --value=VALUE\n'
         '        Type: Optional[int]\n        Default: None',
         help_screen)
     self.assertNotIn('NOTES', help_screen)
@@ -191,7 +193,7 @@ class HelpTest(testutils.BaseTestCase):
     self.assertIn('NAME\n    long_type', help_screen)
     self.assertIn('SYNOPSIS\n    long_type LONG_OBJ', help_screen)
     self.assertNotIn('DESCRIPTION', help_screen)
-    # TODO(dbieber): Assert type is displayed correctly. Type displays
+    # TODO(dbieber): Assert type is displayed correctly. Type displayed
     # differently in Travis vs in Google.
     # self.assertIn(
     #     'POSITIONAL ARGUMENTS\n    LONG_OBJ\n'
@@ -285,7 +287,7 @@ class HelpTest(testutils.BaseTestCase):
     output = helptext.HelpText(
         component=component, trace=trace.FireTrace(component, 'with_default'))
     self.assertIn('NAME\n    with_default', output)
-    self.assertIn('FLAGS\n    --x=X', output)
+    self.assertIn('FLAGS\n    -x, --x=X', output)
 
   @testutils.skipIf(
       six.PY2, 'Python 2 does not support keyword-only arguments.')
@@ -294,7 +296,19 @@ class HelpTest(testutils.BaseTestCase):
     output = helptext.HelpText(
         component=component, trace=trace.FireTrace(component, 'double'))
     self.assertIn('NAME\n    double', output)
-    self.assertIn('FLAGS\n    --count=COUNT (required)', output)
+    self.assertIn('FLAGS\n    -c, --count=COUNT (required)', output)
+
+  @testutils.skipIf(
+      six.PY2,
+      'Python 2 does not support required name-only arguments.')
+  def testHelpTextFunctionMixedDefaults(self):
+    component = tc.py3.HelpTextComponent().identity
+    t = trace.FireTrace(component, name='FunctionMixedDefaults')
+    output = helptext.HelpText(component, trace=t)
+    self.assertIn('NAME\n    FunctionMixedDefaults', output)
+    self.assertIn('FunctionMixedDefaults <flags>', output)
+    self.assertIn('--alpha=ALPHA (required)', output)
+    self.assertIn('--beta=BETA\n        Default: \'0\'', output)
 
   def testHelpScreen(self):
     component = tc.ClassWithDocstring()
@@ -362,7 +376,7 @@ VALUES
         Returns the input multiplied by 2.
 
     FLAGS
-        --count=COUNT
+        -c, --count=COUNT
             Default: 0
             Input number that you want to double."""
     self.assertEqual(textwrap.dedent(expected_output).strip(),
@@ -377,7 +391,8 @@ VALUES
         formatting.Bold('SYNOPSIS') + '\n    triple <flags>',
         help_screen)
     self.assertIn(
-        formatting.Bold('FLAGS') + '\n    --' + formatting.Underline('count'),
+        formatting.Bold('FLAGS') + '\n    -c, --' +
+        formatting.Underline('count'),
         help_screen)
 
   def testHelpTextBoldCommandName(self):
@@ -423,6 +438,21 @@ VALUES
     self.assertIn('double -', help_screen)
     self.assertIn('double - -', help_screen)
 
+  def testHelpTextMultipleKeywoardArgumentsWithShortArgs(self):
+    component = tc.fn_with_multiple_defaults
+    t = trace.FireTrace(component, name='shortargs')
+    help_screen = helptext.HelpText(component, t)
+    self.assertIn(formatting.Bold('NAME') + '\n    shortargs', help_screen)
+    self.assertIn(
+        formatting.Bold('SYNOPSIS') + '\n    shortargs <flags>',
+        help_screen)
+    self.assertIn(
+        formatting.Bold('FLAGS') + '\n    -f, --first',
+        help_screen)
+    self.assertIn('\n    --last', help_screen)
+    self.assertIn('\n    --late', help_screen)
+
+
 
 class UsageTest(testutils.BaseTestCase):
 
@@ -497,6 +527,23 @@ class UsageTest(testutils.BaseTestCase):
         textwrap.dedent(expected_output).lstrip('\n'),
         usage_output)
 
+  @testutils.skipIf(
+      six.PY2,
+      'Python 2 does not support required name-only arguments.')
+  def testUsageOutputFunctionMixedDefaults(self):
+    component = tc.py3.HelpTextComponent().identity
+    t = trace.FireTrace(component, name='FunctionMixedDefaults')
+    usage_output = helptext.UsageText(component, trace=t, verbose=False)
+    expected_output = """
+    Usage: FunctionMixedDefaults <flags>
+      optional flags:        --beta
+      required flags:        --alpha
+
+    For detailed information on this command, run:
+      FunctionMixedDefaults --help"""
+    expected_output = textwrap.dedent(expected_output).lstrip('\n')
+    self.assertEqual(expected_output, usage_output)
+
   def testUsageOutputCallable(self):
     # This is both a group and a command.
     component = tc.CallableWithKeywordArgument()
